@@ -15,7 +15,11 @@ initialsol=NULL){
           kmax<-aux
           warning("the argument kmin should precede the argument kmax.\n Since the value of kmin exceeded that of kmax, they have been swapped \n")}
         p<-dim(mat)[[2]]
-        if (qr(mat)$rank != p) stop("\n The covariance/correlation matrix supplied is not of full rank") 
+        if (qr(mat)$rank != p) stop("\n The covariance/correlation matrix supplied is not of full rank")  
+  	if ( max( abs(mat-t(mat)) ) > 1E-6 ) 
+	    stop("\n The covariance/correlation matrix supplied is not symmetric")
+  	if ( eigen(mat,only.values=TRUE)$values[p] < 0 )
+            stop("\n The covariance/correlation matrix supplied is not positive definite")
         if (kmin >= p) {
              kmin<-p-1
              warning("\n The value of kmin requested is equal to or exceeds the number \n of variables. It has been set at p-1")
